@@ -3,14 +3,13 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Partition a musical duration into rhythmic phrases
 
-our $VERSION = '0.0822';
+our $VERSION = '0.0823';
 
 use Moo;
 use strictures 2;
 use List::Util qw(min);
 use Math::Random::Discrete ();
-use MIDI::Simple ();
-use MIDI::Util qw(reverse_dump);
+use MIDI::Util qw(midi_dump reverse_dump);
 use Music::Duration;
 use namespace::clean;
 
@@ -19,14 +18,14 @@ use constant TICKS => 96;
 
 has size => (
     is      => 'ro',
-    default => sub { return 4 },
+    default => sub { 4 },
 );
 
 
 has pool => (
     is      => 'ro',
     isa     => sub { die 'Empty pool not allowed' unless ref( $_[0] ) eq 'ARRAY' && @{ $_[0] } > 0 },
-    default => sub { return [ keys %MIDI::Simple::Length ] },
+    default => sub { [ keys %{ midi_dump('length') } ] },
 );
 
 has _min_size => (
@@ -37,9 +36,7 @@ has _min_size => (
 
 sub _build__min_size {
     my ($self) = @_;
-
     my @sizes = map { $self->_duration($_) } @{ $self->pool };
-
     return min(@sizes);
 }
 
@@ -65,7 +62,7 @@ has pool_select => (
 
 sub _build_pool_select {
     my ($self) = @_;
-    return sub { return $self->_mrd->rand };
+    return sub { $self->_mrd->rand };
 };
 
 
@@ -101,38 +98,35 @@ has _pool_group => (
 
 sub _build__pool_group {
     my ($self) = @_;
-
     my %pool_group;
     for my $i (0 .. @{ $self->pool } - 1) {
         $pool_group{ $self->pool->[$i] } = $self->groups->[$i];
     }
-
     return \%pool_group;
 }
 
 
 has remainder => (
     is      => 'ro',
-    default => sub { return 1 },
+    default => sub { 1 },
 );
 
 
 has abbreviation => (
     is      => 'ro',
-    default => sub { return 1 },
+    default => sub { 1 },
 );
 
 
 has verbose => (
     is      => 'ro',
-    default => sub { return 0 },
+    default => sub { 0 },
 );
 
 # hash reference of duration lengths (keyed by duration name)
-# Default: \%MIDI::Simple::Length
 has _durations => (
     is      => 'ro',
-    default => sub { return \%MIDI::Simple::Length },
+    default => sub { midi_dump('length') },
 );
 
 
@@ -249,7 +243,7 @@ Music::Duration::Partition - Partition a musical duration into rhythmic phrases
 
 =head1 VERSION
 
-version 0.0822
+version 0.0823
 
 =head1 SYNOPSIS
 
@@ -310,7 +304,7 @@ Default: C<4>
 The list of possible note durations to use in constructing a rhythmic
 motif.
 
-Default: C<[ keys %MIDI::Simple::Length ]> (wn, hn, qn, ...)
+Default: C<[wn, hn, qn, ..., xn, yn, zn]> (see L<Music::Duration>)
 
 This can be either a list of duration names, or duration values,
 specified with a preceding C<d>.  A mixture of both is not well
@@ -422,10 +416,12 @@ L<List::Util>
 
 L<Math::Random::Discrete>
 
-L<MIDI::Simple>
-
 L<Moo>
 
+L<MIDI::Util>
+
+L<Music::Duration>
+
 =head1 AUTHOR
 
 Gene Boggs <gene@cpan.org>
